@@ -214,8 +214,10 @@ class SqleeColumn:
             self.repo.get_file(path=self.path)
             ))
 
+        i = 0
         for data in self.datas:
-            setattr(self, self.namespace[self.datas.index(data)], data)
+            setattr(self, self.namespace[i], data)
+            i += 1
 
         if len(self.datas) != len(self.namespace):
             print(ColumnDataDoesNotFit(namespace=self.namespace, datas=self.datas))
